@@ -33,6 +33,7 @@
 #  define KWAYLANDCLIENT_DECL_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KWAYLANDCLIENT_NO_DEPRECATED
 #    define KWAYLANDCLIENT_NO_DEPRECATED
@@ -84,7 +85,7 @@
 #define KWAYLANDCLIENT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED
-#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
 #endif
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +95,7 @@
 #  ifdef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x57400
 #  endif
 #endif
 
